// function prototypes
Digit getDigit(float num, const int range);
bool insideDigit(vec2 point, float xOffset, Digit d);
bool insideDigit(vec2 point, float xOffset);
bool insideCircle(vec2 curPos, vec2 circleCenter, float radius);

extern int ZeroToOne, ZeroToFive, ZeroToNine;

uniform float hour;
uniform float minute;
uniform float second;

varying vec2 oPosition;

void main()
{
    // separate out the digits for hours/minutes/seconds
    float hourHigh = floor(hour/10.0);
    float hourLow = hour - (hourHigh*10.0);

    float minuteHigh = floor(minute/10.0);
    float minuteLow = minute - (minuteHigh*10.0);

    float secondHigh = floor(second/10.0);
    float secondLow = second - (secondHigh*10.0);

    // turn leading zero digit off for hours 
    if (hourHigh == 0.0) 
        hourHigh = -1.0; 

    Digit hrHigh    = getDigit(hourHigh, ZeroToOne);
    Digit hrLow     = getDigit(hourLow, ZeroToNine);
    Digit minHigh   = getDigit(minuteHigh, ZeroToFive);
    Digit minLow    = getDigit(minuteLow, ZeroToNine);
    Digit secHigh   = getDigit(secondHigh, ZeroToFive);
    Digit secLow    = getDigit(secondLow, ZeroToNine);

    if (insideDigit(oPosition,  1.0, hrHigh) ||
        insideDigit(oPosition,  7.1, hrLow) ||
        insideDigit(oPosition, 15.0, minHigh) ||
        insideDigit(oPosition, 21.1, minLow) ||
        insideDigit(oPosition, 29.0, secHigh) ||
        insideDigit(oPosition, 35.1, secLow) ||

        // four dots for digit separators
        insideCircle(oPosition, vec2(14.0, 9.0), 0.7) ||
        insideCircle(oPosition, vec2(14.0, 5.0), 0.7) ||
        insideCircle(oPosition, vec2(28.0, 9.0), 0.7) ||
        insideCircle(oPosition, vec2(28.0, 5.0), 0.7))
    {
        // lit segments are bright green
        gl_FragColor = vec4(0.0, 1.0, 0.0, 1.0);
    }
    else if (insideDigit(oPosition, 1.0) ||
             insideDigit(oPosition, 7.1) ||
             insideDigit(oPosition, 15.0) ||
             insideDigit(oPosition, 21.1) ||
             insideDigit(oPosition, 29.0) ||
             insideDigit(oPosition, 35.1))
    {
        // unlit segments are dark green
        gl_FragColor = vec4(0.0, 0.2, 0.0, 1.0);
    }
    else
    {
        // fragments outside of any digit are black
        gl_FragColor = vec4(0.0, 0.0, 0.0, 1.0);
    }
}
